🔸ISRO ASAR — PolSARtools 0.8 documentation

Skip to main content
`Ctrl`+`K`

# 🔸ISRO ASAR

## RSLC (`isro_asar`)

The isro_asar function extracts S2/C3/C4/T3 matrix elements from the given ASAR RSLC .h5 file and saves them into a directory.

polsartools.isro_asar(inFile, matrixType='C3', azlks=22, rglks=10, outType='tif', max_workers=None, geocode_flag=False, calibration_constant=42)

  Extracts the S2/C3/T3 matrix elements from a ASAR RSLC HDF5 file and saves them into respective binary files.

  ### Example:

      >>> nisar_rslc("path_to_file.h5", azlks=30, rglks=15)
      This will extract T3 matrix elements from the specified ASAR RSLC file
      and save them in the respective folders.

  ### Parameters:

  inFilestr

    The path to the ASAR RSLC HDF5 file containing the radar data.

  azlksint, optional (default=8)

    The number of azimuth looks for multi-looking.

  rglksint, optional (default=6)

    The number of range looks for multi-looking.

  matrixTypestr, optional (default = T3)

    Type of matrix to extract. Valid options are ‘S2’, ‘C3’, and ‘T3’.

  ### Returns:

  None

    The function does not return any value. Instead, it creates a folder named C2/S2/C3/T3 (if not already present) and saves the following raster files:

  ### Raises:

  Exception

    If the RSLC HDF5 file is invalid or cannot be read.